Continued with rewrites:
[core.git] / index.php
index ca598d09a38e399e38c126ba94ec54dc72459815..ecf66b48876f5635b4848a966b756595673f1fec 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,4 +1,18 @@
 <?php
+// Own namespace (watch out: core)
+namespace CoreFramework\EntryPoint;
+
+// Import framework stuff
+use CoreFramework\Configuration\FrameworkConfiguration;
+use CoreFramework\Factory\ObjectFactory;
+use CoreFramework\Helper\Application\ApplicationHelper;
+use CoreFramework\Localization\LanguageSystem;
+use CoreFramework\Loader\ClassLoader;
+use CoreFramework\Generic\FrameworkException;
+
+// Import SPL stuff
+use \Exception;
+
 /**
  * The main class with the entry point to the whole application. This class
  * "emulates" Java's entry point call. Additionally it covers local
@@ -28,9 +42,9 @@
  */
 final class ApplicationEntryPoint {
        /**
-        * Core path
+        * Framework path
         */
-       private static $corePath = '';
+       private static $frameworkPath = '';
 
        /**
         * The application's emergency exit
@@ -117,7 +131,7 @@ final class ApplicationEntryPoint {
                        $applicationInstance = NULL;
 
                        // Is the class there?
-                       if (class_exists('ApplicationHelper')) {
+                       if (class_exists('CoreFramework\Helper\Application\ApplicationHelper')) {
                                // Get application instance
                                $applicationInstance = ApplicationHelper::getSelfInstance();
 
@@ -150,7 +164,7 @@ final class ApplicationEntryPoint {
 
                                // Flush the response
                                $responseInstance->flushBuffer();
-                       } catch (FileIoException $e) {
+                       } catch (FileNotFoundException $e) {
                                // Even the template 'emergency_exit' wasn't found so output both message
                                exit($message . ', exception: ' . $e->getMessage());
                        }
@@ -166,44 +180,79 @@ final class ApplicationEntryPoint {
        }
 
        /**
-        * Determines the correct absolute path for all includes only once per run.
-        * Other calls of this method are being "cached".
+        * Determines the correct absolute path for the framework. A set of common
+        * paths is being tested (first most common for applications, second when
+        * core tests are being executed and third/forth if the framework has been
+        * cloned there).
         *
-        * @return      $corePath       Base path (core) for all includes
+        * @return      $frameworkPath  Path for framework
         */
-       protected static final function detectCorePath () {
+       public static final function detectFrameworkPath () {
                // Is it not set?
-               if (empty(self::$corePath)) {
-                       // Auto-detect our core path
-                       self::$corePath = str_replace("\\", '/', dirname(__FILE__));
+               if (empty(self::$frameworkPath)) {
+                       // Auto-detect core path (first application-common)
+                       foreach (array('core', '.', '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
+                               // Create full path for testing
+                               $realPath = realpath($possiblePath);
+
+                               // Debug message
+                               //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
+
+                               // Is it FALSE?
+                               if ($realPath === FALSE) {
+                                       // Then, not found.
+                                       continue;
+                               } // END - if
+
+                               // First create full-qualified file name (FQFN) to framework/config.inc.php
+                               $fqfn = sprintf(
+                                       '%s%sframework%sconfig.inc.php',
+                                       $realPath,
+                                       DIRECTORY_SEPARATOR,
+                                       DIRECTORY_SEPARATOR,
+                                       $possiblePath
+                               );
+
+                               // Debug message
+                               /* NOISY-DEBUG: */ printf('[%s:%d]: fqfn=%s' . PHP_EOL, __METHOD__, __LINE__, $fqfn);
+
+                               // Is it readable?
+                               if (is_readable($fqfn)) {
+                                       // Found one
+                                       self::$frameworkPath = $realPath . '/framework/';
+
+                                       // Abort here
+                                       break;
+                               } // END - if
+                       } // END - foreach
+
+                       // Able to find?
+                       if (!is_dir(self::$frameworkPath)) {
+                               // Is no directory
+                               throw new Exception('Cannot find framework.');
+                       } // END - if
                } // END - if
 
                // Return it
-               return self::$corePath;
+               return self::$frameworkPath;
        }
 
        /**
* The application's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
-        * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java.
+        * concerns. This is done here to "emulate" the well-known entry point in
+        * Java.
         *
         * @return      void
         */
        public static final function main () {
-               // Load config file
-               require(self::detectCorePath() . '/inc/config.php');
+               // Load bootstrap file
+               require(self::detectFrameworkPath() . 'bootstrap/bootstrap.inc.php');
 
-               // Load all include files
-               require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
-
-               // Load all framework classes
-               require($cfg->getConfigEntry('base_path') . 'inc/classes.php');
-
-               // Include the application selector
-               require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
-       } // END - main()
-} // END - class
+               // Get a new configuration instance
+               $cfg = FrameworkConfiguration::getSelfInstance();
+       }
+}
 
 // Developer mode active? Comment out if no dev!
 define('DEVELOPER', TRUE);
@@ -213,8 +262,5 @@ define('DEVELOPER', TRUE);
 
 //xdebug_start_trace();
 
-// Do not remove the following line:
+// Call above main() method
 ApplicationEntryPoint::main();
-
-// [EOF]
-?>
@@ -166,44 +180,79 @@ final class ApplicationEntryPoint {
 
        /**
-        * The application's main entry point. This class isolates some local
+        * The framework's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security